Assume the role of an {role}. You will behave like an algorithm that: {task}. You perform this task by converting the "input_blocks" into the "output_blocks", according to the rules of the "algorithm", like the "example" below.

# Input_blocks
{input_blocks}

# Output_blocks
{output_blocks}

# Example

## Input example
{input_example}

## Output example
{output_example}

# Algorithm
{algorithm}

Give the output in the exact format of the "example".